==> cayenne-server-3.0M3-sources.jar: org/apache/cayenne/dba/frontbase/FrontBaseSelectTranslator.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.dba.frontbase;

import org.apache.cayenne.access.trans.SelectTranslator;

/**
 * @since 1.2
 * @author Andrus Adamchik
 */
class FrontBaseSelectTranslator extends SelectTranslator {

    static final String SELECT_PREFIX = "SELECT";

    @Override
    public String createSqlString() throws Exception {
        String sql = super.createSqlString();

        // limit results
        int limit = getQuery().getMetaData(getEntityResolver()).getFetchLimit();
        if (limit > 0 && sql.startsWith(SELECT_PREFIX)) {
            return SELECT_PREFIX
                    + " TOP "
                    + limit
                    + sql.substring(SELECT_PREFIX.length());
        }

        return sql;
    }
}

==> cayenne-server-3.1M3-sources.jar: org/apache/cayenne/dba/frontbase/FrontBaseSelectTranslator.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.dba.frontbase;

import org.apache.cayenne.access.trans.SelectTranslator;

/**
 * @since 1.2
 */
class FrontBaseSelectTranslator extends SelectTranslator {

    static final String SELECT_PREFIX = "SELECT";

    @Override
    protected void appendLimitAndOffsetClauses(StringBuilder buffer) {

        int limit = queryMetadata.getFetchLimit();
        if (limit > 0 && buffer.length() > SELECT_PREFIX.length()) {

            if (SELECT_PREFIX.equals(buffer.substring(0, SELECT_PREFIX.length()))) {
                buffer.insert(SELECT_PREFIX.length(), " TOP " + limit);
            }
        }
    }
}
